# Coil Calculator Program written in Tcl/TK

proc CoilCalculator_ui {root args} {

	# this treats "." as a special case

	if {$root == "."} {
	    set base ""
	} else {
	    set base $root
	}
    
	label $base.lblInnerRadius \
		-text {Inner Radius (mm)}

	entry $base.entInnerRadius \
		-justify center \
		-textvariable innerRadius

	label $base.lblWireThickness \
		-text {Wire Thickness (mm)}

	entry $base.entwireThickness \
		-justify center \
		-textvariable wireThickness
	catch {
		$base.entwireThickness configure \
			-font {-*-MS Sans Serif-Medium-R-Normal-*-*-80-*-*-*-*-*-*}
	}

	label $base.lblNumOfTurns \
		-text {Number of Turns}

	entry $base.entNumOfTurns \
		-justify center \
		-textvariable numberOfTurns

	label $base.lblMeanRadius \
		-text {Mean Radius (mm)}

	entry $base.entMeanRadius \
		-background bisque \
		-justify center \
		-state disabled \
		-textvariable meanRadius
	catch {
		$base.entMeanRadius configure \
			-font {-*-MS Sans Serif-Medium-R-Normal-*-*-80-*-*-*-*-*-*}
	}

	label $base.lblCoilThickness \
		-text {Coil Thickness (mm)}

	entry $base.entCoilThickness \
		-background bisque \
		-justify center \
		-state disabled \
		-textvariable coilThickness

	label $base.lblInductance \
		-text {Inductance (mH)}

	entry $base.entInductance \
		-background bisque \
		-justify center \
		-state disabled \
		-textvariable inductance

	button $base.cmdCalculate \
		-command cmdCalculate \
		-text Calculate


	# Geometry management

	grid $base.lblInnerRadius -in $root	-row 1 -column 1 
	grid $base.entInnerRadius -in $root	-row 1 -column 2 
	grid $base.lblWireThickness -in $root	-row 2 -column 1 
	grid $base.entwireThickness -in $root	-row 2 -column 2 
	grid $base.lblNumOfTurns -in $root	-row 3 -column 1 
	grid $base.entNumOfTurns -in $root	-row 3 -column 2 
	grid $base.lblMeanRadius -in $root	-row 4 -column 1 
	grid $base.entMeanRadius -in $root	-row 4 -column 2 
	grid $base.lblCoilThickness -in $root	-row 5 -column 1 
	grid $base.entCoilThickness -in $root	-row 5 -column 2 
	grid $base.lblInductance -in $root	-row 6 -column 1 
	grid $base.entInductance -in $root	-row 6 -column 2 
	grid $base.cmdCalculate -in $root	-row 7 -column 2 

	# Resize behavior management

	grid rowconfigure $root 1 -weight 0 -minsize 30
	grid rowconfigure $root 2 -weight 0 -minsize 30
	grid rowconfigure $root 3 -weight 0 -minsize 30
	grid rowconfigure $root 4 -weight 0 -minsize 30
	grid rowconfigure $root 5 -weight 0 -minsize 30
	grid rowconfigure $root 6 -weight 0 -minsize 30
	grid rowconfigure $root 7 -weight 0 -minsize 30
	grid columnconfigure $root 1 -weight 0 -minsize 30
	grid columnconfigure $root 2 -weight 0 -minsize 30

# Coil Calculations

set .title "Coil Calculator"

proc cmdCalculate {} {
  global innerRadius wireThickness numberOfTurns
  global meanRadius coilThickness inductance
  set pi 3.14159
  set N $numberOfTurns
  set w $wireThickness
  set c [expr sqrt([expr $N * $w])]
  set a [expr $innerRadius + $c / 2]
  set x [expr pow([expr $c / 2 / $a], 2)]
  set s1 [expr 0.0000004 * $pi * $a]
  set s2 [expr pow($N,2)]
  set s3 [expr $s1 * $s2]
  set s4 [expr 0.5 + [expr $x / 12]]
  set s5 [expr log(8 / $x)]
  set s6 [expr 0.85 + 0.2 * $x]
  set s7 [expr $s4 * $s5 - $s6]
  set L [expr $s3 * $s7]
  set meanRadius [format "%.2f" $a]
  set coilThickness [format "%.2f" $c]
  set inductance [format "%.2f" $L]
}

# End of coil calculations

}
